@@ -3,10 +3,10 @@ from typing import Any, Literal
 import pandas as pd
 from pydantic import BaseModel, ConfigDict, Field, field_validator, model_serializer
 
-from .annos import RangeAnnotation, TextAnnotation
 from .base import BaseChart
 from .enums import DateFormat, NumberFormat, ReplaceFlagsType, ValueLabelAlignment
-from .serializers import ColorCategory, CustomRange, ModelListSerializer, ReplaceFlags
+from .models import AnnotationsMixin
+from .serializers import ColorCategory, CustomRange, ReplaceFlags
 
 
 class BarOverlay(BaseModel):
@@ -75,7 +75,7 @@ class BarOverlay(BaseModel):
     )
 
 
-class BarChart(BaseChart):
+class BarChart(AnnotationsMixin, BaseChart):
     """A base class for the Datawrapper API's bar chart."""
 
     model_config = ConfigDict(
@@ -281,11 +281,11 @@ class BarChart(BaseChart):
         description="The default color for the chart (palette index or hex string)",
     )
 
-    #: The column with the color for the bars
+    #: The name of the column with the color for the bars
     color_column: str = Field(
         default="",
         alias="color-column",
-        description="The column with the color for the bars",
+        description="The name of the column with the color for the bars",
     )
 
     #: A mapping of layer names to colors
@@ -342,11 +342,11 @@ class BarChart(BaseChart):
         description="Whether to reverse the sort order",
     )
 
-    #: Whether to group the bars by a second column
-    group_by_column: str = Field(
-        default="",
-        alias="group-by-column",
-        description="Whether to group the bars by a second column",
+    #: The column to use for grouping bars
+    groups_column: str | None = Field(
+        default=None,
+        alias="groups-column",
+        description="The column to use for grouping bars",
     )
 
     #: Whether to show the group labels
@@ -384,20 +384,6 @@ class BarChart(BaseChart):
         description="A list of the highlighted series",
     )
 
-    #: A list of text annotations to display on the chart
-    text_annotations: list[TextAnnotation | dict[Any, Any]] = Field(
-        default_factory=list,
-        alias="text-annotations",
-        description="A list of text annotations to display on the chart",
-    )
-
-    #: A list of range annotations to display on the chart
-    range_annotations: list[RangeAnnotation | dict[Any, Any]] = Field(
-        default_factory=list,
-        alias="range-annotations",
-        description="A list of range annotations to display on the chart",
-    )
-
     @field_validator("replace_flags")
     @classmethod
     def validate_replace_flags(
@@ -452,22 +438,20 @@ class BarChart(BaseChart):
                 # Sorting and grouping
                 "sort-bars": self.sort_bars,
                 "reverse-order": self.reverse_order,
-                "group-by-column": self.group_by_column != "",
+                "group-by-column": self.groups_column is not None
+                and self.groups_column != "",
                 "show-group-labels": self.show_group_labels,
                 "show-category-labels": self.show_category_labels,
                 # Overlays
                 "overlays": [],
                 # Annotations
                 "highlighted-series": self.highlighted_series,
-                "text-annotations": ModelListSerializer.serialize(
-                    self.text_annotations, TextAnnotation
-                ),
-                "range-annotations": ModelListSerializer.serialize(
-                    self.range_annotations, RangeAnnotation
-                ),
             }
         )
 
+        # Add annotations
+        model["metadata"]["visualize"].update(self._serialize_annotations())
+
         # Add the overlays, if any
         for overlay_obj in self.overlays:
             # If the overlay is a dictionary, validate it and convert it to a BarOverlay object
@@ -485,13 +469,18 @@ class BarChart(BaseChart):
             model["metadata"]["visualize"]["overlays"].append(overlay_dict)
 
         # Add axes configuration to metadata
-        model["metadata"]["axes"] = {
+        axes_config = {
             "colors": self.color_column or self.label_column,
             "bars": self.bar_column,
             "labels": self.label_column,
-            "groups": self.group_by_column,
         }
 
+        # Only add groups if it's set
+        if self.groups_column:
+            axes_config["groups"] = self.groups_column
+
+        model["metadata"]["axes"] = axes_config
+
         # Return the serialized data
         return model
 
@@ -585,29 +574,30 @@ class BarChart(BaseChart):
         if "reverse-order" in visualize:
             init_data["reverse_order"] = visualize["reverse-order"]
         if "groups" in axes:
-            init_data["group_by_column"] = axes["groups"]
+            init_data["groups_column"] = axes["groups"]
         if "show-group-labels" in visualize:
             init_data["show_group_labels"] = visualize["show-group-labels"]
         if "show-category-labels" in visualize:
             init_data["show_category_labels"] = visualize["show-category-labels"]
 
-        # Overlays (list of BarOverlay objects)
+        # Overlays (can be dict with UUID keys or list of BarOverlay objects)
         if "overlays" in visualize:
-            overlays_list = visualize["overlays"]
-            init_data["overlays"] = [
-                BarOverlay.model_validate(overlay) for overlay in overlays_list
-            ]
+            overlays_data = visualize["overlays"]
+            # Handle both dict (with UUID keys) and list formats
+            if isinstance(overlays_data, dict):
+                init_data["overlays"] = [
+                    BarOverlay.model_validate(overlay)
+                    for overlay in overlays_data.values()
+                ]
+            elif isinstance(overlays_data, list):
+                init_data["overlays"] = [
+                    BarOverlay.model_validate(overlay) for overlay in overlays_data
+                ]
 
         # Annotations
         if "highlighted-series" in visualize:
             init_data["highlighted_series"] = visualize["highlighted-series"]
 
-        # Annotations
-        init_data["text_annotations"] = TextAnnotation.deserialize_model(
-            visualize.get("text-annotations")
-        )
-        init_data["range_annotations"] = RangeAnnotation.deserialize_model(
-            visualize.get("range-annotations")
-        )
+        init_data.update(cls._deserialize_annotations(visualize))
 
         return init_data
