@@ -1,6 +1,6 @@
 """Enum classes for Datawrapper chart formatting and styling options."""
 
-from .connector_line import ArrowHead, ConnectorLineType, StrokeWidth
+from .annos import ArrowHead, ConnectorLineType, StrokeType, StrokeWidth
 from .date_format import DateFormat
 from .grid_display import GridDisplay
 from .grid_label import GridLabelAlign, GridLabelPosition
@@ -19,6 +19,7 @@ from .scatter_shape import (
     ScatterSize,
 )
 from .symbol_shape import SymbolDisplay, SymbolShape, SymbolStyle
+from .text_align import TextAlign
 from .value_label import (
     ValueLabelAlignment,
     ValueLabelDisplay,
@@ -45,10 +46,12 @@ __all__ = [
     "ScatterGridLines",
     "ScatterShape",
     "ScatterSize",
+    "StrokeType",
     "StrokeWidth",
     "SymbolDisplay",
     "SymbolShape",
     "SymbolStyle",
+    "TextAlign",
     "ValueLabelAlignment",
     "ValueLabelDisplay",
     "ValueLabelMode",
