@@ -1,9 +1,15 @@
+from collections.abc import Sequence
 from typing import Any, Literal
 
 import pandas as pd
-from pydantic import ConfigDict, Field, field_validator, model_serializer
+from pydantic import (
+    ConfigDict,
+    Field,
+    field_validator,
+    model_serializer,
+    model_validator,
+)
 
-from .annos import RangeAnnotation, TextAnnotation
 from .base import BaseChart
 from .enums import (
     DateFormat,
@@ -15,19 +21,317 @@ from .enums import (
     ValueLabelDisplay,
     ValueLabelPlacement,
 )
+from .models import (
+    AnnotationsMixin,
+    CustomRangeMixin,
+    CustomTicksMixin,
+    GridDisplayMixin,
+    GridFormatMixin,
+    RangeAnnotation,
+    TextAnnotation,
+)
 from .serializers import (
     ColorCategory,
-    CustomRange,
-    CustomTicks,
-    ModelListSerializer,
     NegativeColor,
     PlotHeight,
     ValueLabels,
 )
 
 
-class MultipleColumnChart(BaseChart):
-    """A base class for the Datawrapper API's multiple column chart."""
+class MultipleColumnTextAnnotation(TextAnnotation):
+    """Text annotation with additional fields specific to MultipleColumnChart.
+
+    This subclass extends TextAnnotation to support multi-panel charts where
+    annotations can be associated with specific plots/panels.
+
+    Attributes:
+        plot: Which plot/panel this annotation applies to (e.g., "Paris", "London")
+        showInAllPlots: Whether to show this annotation in all plots (defaults to False)
+    """
+
+    #: Which plot/panel this annotation applies to
+    plot: str | None = Field(
+        default=None,
+        description="Which plot/panel this annotation applies to",
+    )
+
+    #: Whether to show this annotation in all plots
+    show_in_all_plots: bool = Field(
+        default=False,
+        alias="showInAllPlots",
+        description="Whether to show this annotation in all plots",
+    )
+
+    def serialize_model(self) -> dict:
+        """Serialize the annotation to API format.
+
+        Extends the base TextAnnotation serialization to include:
+        - plot field inside the position object
+        - showInAllPlots field at the top level
+
+        Returns:
+            Dictionary in Datawrapper API format
+        """
+        result = super().serialize_model()
+
+        # Add plot to position object if specified
+        if self.plot is not None:
+            result["position"]["plot"] = self.plot
+
+        # Always include showInAllPlots at top level
+        result["showInAllPlots"] = self.show_in_all_plots
+
+        return result
+
+    @classmethod
+    def deserialize_model(
+        cls, api_data: dict[str, dict[Any, Any]] | list[dict[Any, Any]] | None
+    ) -> list[dict]:
+        """Parse API response to extract MultipleColumnTextAnnotation data.
+
+        Handles the API format where:
+        - x, y, and plot are inside the position object
+        - showInAllPlots is at the top level
+        - Connector lines with enabled=False are converted to None
+
+        Args:
+            api_data: API response data (dict with UUID keys or list format)
+
+        Returns:
+            List of dictionaries that can initialize MultipleColumnTextAnnotation instances
+        """
+        if not api_data:
+            return []
+
+        # First, call parent class to handle base fields including connector line logic
+        base_result = TextAnnotation.deserialize_model(api_data)
+
+        # Now enhance with MultipleColumnChart-specific fields
+        result = []
+        for i, anno_dict in enumerate(base_result):
+            # Extract plot from the original API data
+            if isinstance(api_data, dict):
+                # Find the original annotation data by ID (if present)
+                anno_id = anno_dict.get("id")
+                original_data = api_data.get(anno_id, {}) if anno_id else {}
+            else:
+                # For list format, use index to find original data
+                original_data = api_data[i] if i < len(api_data) else {}
+
+            # Extract plot from position object
+            position = original_data.get("position", {})
+            if isinstance(position, dict) and "plot" in position:
+                anno_dict["plot"] = position["plot"]
+
+            # Extract showInAllPlots (defaults to False for text annotations)
+            anno_dict["show_in_all_plots"] = original_data.get("showInAllPlots", False)
+
+            result.append(anno_dict)
+
+        return result
+
+
+class MultipleColumnRangeAnnotation(RangeAnnotation):
+    """Range annotation with additional fields specific to MultipleColumnChart.
+
+    This subclass extends RangeAnnotation to support multi-panel charts where
+    annotations can be associated with specific plots/panels.
+
+    Attributes:
+        plot: Which plot/panel this annotation applies to (e.g., "Paris", "London")
+        showInAllPlots: Whether to show this annotation in all plots (defaults to True)
+    """
+
+    #: Which plot/panel this annotation applies to
+    plot: str | None = Field(
+        default=None,
+        description="Which plot/panel this annotation applies to",
+    )
+
+    #: Whether to show this annotation in all plots
+    show_in_all_plots: bool = Field(
+        default=True,
+        alias="showInAllPlots",
+        description="Whether to show this annotation in all plots",
+    )
+
+    def serialize_model(self) -> dict:
+        """Serialize the annotation to API format.
+
+        Extends the base RangeAnnotation serialization to include:
+        - plot field inside the position object
+        - showInAllPlots field at the top level
+
+        Returns:
+            Dictionary in Datawrapper API format
+        """
+        result = super().serialize_model()
+
+        # Add plot to position object if specified
+        if self.plot is not None:
+            result["position"]["plot"] = self.plot
+
+        # Always include showInAllPlots at top level
+        result["showInAllPlots"] = self.show_in_all_plots
+
+        return result
+
+    @classmethod
+    def deserialize_model(
+        cls, api_data: dict[str, dict[Any, Any]] | list[dict[Any, Any]] | None
+    ) -> list[dict]:
+        """Parse API response to extract MultipleColumnRangeAnnotation data.
+
+        Handles the API format where:
+        - plot is inside the position object
+        - showInAllPlots is at the top level
+
+        Args:
+            api_data: API response data (dict with UUID keys or list format)
+
+        Returns:
+            List of dictionaries that can initialize MultipleColumnRangeAnnotation instances
+        """
+        if not api_data:
+            return []
+
+        result = []
+
+        # Handle dict format (UUID keys from API)
+        if isinstance(api_data, dict):
+            items_to_process = list(api_data.items())
+        else:
+            # Handle list format - generate temporary IDs
+            items_to_process = [(f"temp-{i}", anno) for i, anno in enumerate(api_data)]
+
+        for anno_id, anno_data in items_to_process:
+            # Extract position data
+            position = anno_data.get("position", {})
+            plot = position.get("plot") if isinstance(position, dict) else None
+            x0 = position.get("x0") if isinstance(position, dict) else None
+            x1 = position.get("x1") if isinstance(position, dict) else None
+            y0 = position.get("y0") if isinstance(position, dict) else None
+            y1 = position.get("y1") if isinstance(position, dict) else None
+
+            # Extract showInAllPlots (defaults to True)
+            show_in_all = anno_data.get("showInAllPlots", True)
+
+            # Build annotation dict with id
+            anno_dict = {**anno_data, "id": anno_id}
+
+            # Add position fields
+            if x0 is not None:
+                anno_dict["x0"] = x0
+            if x1 is not None:
+                anno_dict["x1"] = x1
+            if y0 is not None:
+                anno_dict["y0"] = y0
+            if y1 is not None:
+                anno_dict["y1"] = y1
+
+            # Add MultipleColumnChart-specific fields
+            if plot is not None:
+                anno_dict["plot"] = plot
+            anno_dict["show_in_all_plots"] = show_in_all
+
+            result.append(anno_dict)
+        return result
+
+
+class MultipleColumnXRangeAnnotation(MultipleColumnRangeAnnotation):
+    """A horizontal range annotation for MultipleColumnChart.
+
+    This is a convenience class that automatically sets type="x" and display="range",
+    and validates that both x0 and x1 are provided.
+    """
+
+    def __init__(self, **data):
+        data.setdefault("type", "x")
+        data.setdefault("display", "range")
+        super().__init__(**data)
+
+    @model_validator(mode="after")
+    def validate_x_positions_required(self) -> "MultipleColumnXRangeAnnotation":
+        if self.x0 is None or self.x1 is None:
+            raise ValueError(
+                "MultipleColumnXRangeAnnotation requires both x0 and x1 to be set"
+            )
+        return self
+
+
+class MultipleColumnYRangeAnnotation(MultipleColumnRangeAnnotation):
+    """A vertical range annotation for MultipleColumnChart.
+
+    This is a convenience class that automatically sets type="y" and display="range",
+    and validates that both y0 and y1 are provided.
+    """
+
+    def __init__(self, **data):
+        data.setdefault("type", "y")
+        data.setdefault("display", "range")
+        super().__init__(**data)
+
+    @model_validator(mode="after")
+    def validate_y_positions_required(self) -> "MultipleColumnYRangeAnnotation":
+        if self.y0 is None or self.y1 is None:
+            raise ValueError(
+                "MultipleColumnYRangeAnnotation requires both y0 and y1 to be set"
+            )
+        return self
+
+
+class MultipleColumnXLineAnnotation(MultipleColumnRangeAnnotation):
+    """A vertical line annotation for MultipleColumnChart.
+
+    This is a convenience class that automatically sets type="x" and display="line",
+    and validates that x0 is provided.
+    """
+
+    def __init__(self, **data):
+        data.setdefault("type", "x")
+        data.setdefault("display", "line")
+        super().__init__(**data)
+
+    @model_validator(mode="after")
+    def validate_x_position_required(self) -> "MultipleColumnXLineAnnotation":
+        if self.x0 is None:
+            raise ValueError("MultipleColumnXLineAnnotation requires x0 to be set")
+        return self
+
+
+class MultipleColumnYLineAnnotation(MultipleColumnRangeAnnotation):
+    """A horizontal line annotation for MultipleColumnChart.
+
+    This is a convenience class that automatically sets type="y" and display="line",
+    and validates that y0 is provided.
+    """
+
+    def __init__(self, **data):
+        data.setdefault("type", "y")
+        data.setdefault("display", "line")
+        super().__init__(**data)
+
+    @model_validator(mode="after")
+    def validate_y_position_required(self) -> "MultipleColumnYLineAnnotation":
+        if self.y0 is None:
+            raise ValueError("MultipleColumnYLineAnnotation requires y0 to be set")
+        return self
+
+
+class MultipleColumnChart(
+    GridDisplayMixin,
+    GridFormatMixin,
+    CustomRangeMixin,
+    CustomTicksMixin,
+    AnnotationsMixin,
+    BaseChart,
+):
+    """A base class for the Datawrapper API's multiple column chart.
+
+    Note: This chart uses MultipleColumnTextAnnotation and MultipleColumnRangeAnnotation
+    for annotations, which extend the base annotation classes with plot-specific fields.
+    The parent AnnotationsMixin fields accept these subclasses automatically.
+    """
 
     model_config = ConfigDict(
         populate_by_name=True,
@@ -131,34 +435,6 @@ class MultipleColumnChart(BaseChart):
     # Horizontal axis
     #
 
-    #: The custom range for the x axis
-    custom_range_x: tuple[Any, Any] | list[Any] = Field(
-        default=("", ""),
-        alias="custom-range-x",
-        description="The custom range for the x axis",
-    )
-
-    #: The custom ticks for the x axis
-    custom_ticks_x: list[Any] = Field(
-        default_factory=list,
-        alias="custom-ticks-x",
-        description="The custom ticks for the x axis",
-    )
-
-    #: The formatting for the x grid labels
-    x_grid_format: str = Field(
-        default="auto",
-        alias="x-grid-format",
-        description="The formatting for the x grid labels",
-    )
-
-    #: Whether to show the x grid
-    x_grid: GridDisplay | str = Field(
-        default="off",
-        alias="x-grid",
-        description="Whether to show the x grid",
-    )
-
     #: The labeling of the x axis
     x_grid_labels: Literal["on", "off"] = Field(
         default="on",
@@ -177,34 +453,6 @@ class MultipleColumnChart(BaseChart):
     # Vertical axis
     #
 
-    #: The custom range for the y axis
-    custom_range_y: tuple[Any, Any] | list[Any] = Field(
-        default=("", ""),
-        alias="custom-range-y",
-        description="The custom range for the y axis",
-    )
-
-    #: The custom ticks for the y axis
-    custom_ticks_y: list[Any] = Field(
-        default_factory=list,
-        alias="custom-ticks-y",
-        description="The custom ticks for the y axis",
-    )
-
-    #: The formatting for the y grid labels (use DateFormat or NumberFormat enum or custom format strings)
-    y_grid_format: DateFormat | NumberFormat | str = Field(
-        default="",
-        alias="y-grid-format",
-        description="The formatting for the y grid labels. Use DateFormat for temporal data, NumberFormat for numeric data, or provide custom format strings.",
-    )
-
-    #: Whether to show the y grid lines
-    y_grid: bool = Field(
-        default=True,
-        alias="y-grid",
-        description="Whether to show the y grid lines",
-    )
-
     #: The labeling of the y grid labels
     y_grid_labels: GridLabelPosition | str = Field(
         default="outside",
@@ -282,6 +530,52 @@ class MultipleColumnChart(BaseChart):
                 raise ValueError(f"Invalid value: {v}. Must be one of {valid_values}")
         return v
 
+    @field_validator("text_annotations", mode="before")
+    @classmethod
+    def convert_text_annotations(
+        cls, v: Sequence[MultipleColumnTextAnnotation | dict[Any, Any]]
+    ) -> list[MultipleColumnTextAnnotation]:
+        """Convert dict annotations to MultipleColumnTextAnnotation instances.
+
+        This ensures that when annotations are passed as dicts, they are converted
+        to the proper annotation class so that serialize_model() includes the plot field.
+        """
+        if not v:
+            return []
+
+        result = []
+        for item in v:
+            if isinstance(item, dict):
+                # Convert dict to MultipleColumnTextAnnotation instance
+                result.append(MultipleColumnTextAnnotation(**item))
+            else:
+                # Already an instance, keep as is
+                result.append(item)
+        return result
+
+    @field_validator("range_annotations", mode="before")
+    @classmethod
+    def convert_range_annotations(
+        cls, v: Sequence[MultipleColumnRangeAnnotation | dict[Any, Any]]
+    ) -> list[MultipleColumnRangeAnnotation]:
+        """Convert dict annotations to MultipleColumnRangeAnnotation instances.
+
+        This ensures that when annotations are passed as dicts, they are converted
+        to the proper annotation class so that serialize_model() includes the plot field.
+        """
+        if not v:
+            return []
+
+        result = []
+        for item in v:
+            if isinstance(item, dict):
+                # Convert dict to MultipleColumnRangeAnnotation instance
+                result.append(MultipleColumnRangeAnnotation(**item))
+            else:
+                # Already an instance, keep as is
+                result.append(item)
+        return result
+
     #
     # Tooltips
     #
@@ -327,7 +621,7 @@ class MultipleColumnChart(BaseChart):
 
     #: Whether or not to show value labels
     show_value_labels: ValueLabelDisplay | str = Field(
-        default="hover",
+        default="off",
         alias="show-value-labels",
         description="Whether or not to show value labels",
     )
@@ -360,24 +654,6 @@ class MultipleColumnChart(BaseChart):
         description="Show label for all panels",
     )
 
-    #
-    # Annotations
-    #
-
-    #: A list of text annotations to display on the chart
-    text_annotations: list[dict[Any, Any]] = Field(
-        default_factory=list,
-        alias="text-annotations",
-        description="A list of text annotations to display on the chart",
-    )
-
-    #: A list of range annotations to display on the chart
-    range_annotations: list[dict[Any, Any]] = Field(
-        default_factory=list,
-        alias="range-annotations",
-        description="A list of range annotations to display on the chart",
-    )
-
     @model_serializer
     def serialize_model(self) -> dict:
         """Serialize the model to a dictionary."""
@@ -385,77 +661,72 @@ class MultipleColumnChart(BaseChart):
         model = super().serialize_model()
 
         # Add chart specific properties to visualize section
-        model["metadata"]["visualize"].update(
-            {
-                # Layout
-                "gridLayout": self.grid_layout,
-                "gridColumnCount": self.grid_column,
-                "gridColumnCountMobile": self.grid_column_mobile,
-                "gridColumnMinWidth": self.grid_column_width,
-                "gridRowHeightFixed": self.grid_row_height,
-                "sort": {
-                    "enabled": self.sort,
-                    "reverse": self.sort_reverse,
-                    "by": self.sort_by,
-                },
-                # Horizontal axis
-                "custom-range-x": CustomRange.serialize(self.custom_range_x),
-                "custom-ticks-x": CustomTicks.serialize(self.custom_ticks_x),
-                "x-grid-format": self.x_grid_format,
-                "x-grid-labels": self.x_grid_labels,
-                "x-grid": self.x_grid_all,
-                "grid-lines-x": {
-                    "type": "" if self.x_grid == "off" else self.x_grid,
-                    "enabled": self.x_grid != "off",
-                },
-                # Vertical axis
-                "custom-range-y": CustomRange.serialize(self.custom_range_y),
-                "custom-ticks-y": CustomTicks.serialize(self.custom_ticks_y),
-                "y-grid-format": self.y_grid_format,
-                "grid-lines": self.y_grid,
-                "yAxisLabels": {
-                    "enabled": self.y_grid_labels != "off",
-                    "alignment": self.y_grid_label_align,
-                    "placement": ""
-                    if self.y_grid_labels == "off"
-                    else self.y_grid_labels,
-                },
-                # Appearance
-                "base-color": self.base_color,
-                "negativeColor": NegativeColor.serialize(self.negative_color),
-                "bar-padding": self.bar_padding,
-                "color-category": ColorCategory.serialize(self.color_category),
-                "color-by-column": bool(self.color_category),
-                **PlotHeight.serialize(
-                    self.plot_height_mode,
-                    self.plot_height_fixed,
-                    self.plot_height_ratio,
-                ),
-                "panels": {panel["column"]: panel for panel in self.panels},
-                # Tooltips
-                "show-tooltips": self.show_tooltips,
-                "syncMultipleTooltips": self.sync_multiple_tooltips,
-                "tooltip-number-format": self.tooltip_number_format,
-                # Labels
-                "show-color-key": self.show_color_key,
-                "label-colors": self.label_colors,
-                "label-margin": self.label_margin,
-                **ValueLabels.serialize(
-                    self.show_value_labels,
-                    self.value_labels_format,
-                    placement=self.value_labels_placement,
-                    chart_type="multiple-column",
-                ),
-                "xGridLabelAllColumns": self.x_grid_label_all,
-                # Annotations
-                "text-annotations": ModelListSerializer.serialize(
-                    self.text_annotations, TextAnnotation
-                ),
-                "range-annotations": ModelListSerializer.serialize(
-                    self.range_annotations, RangeAnnotation
-                ),
-            }
-        )
+        visualize_data = {
+            # Layout
+            "gridLayout": self.grid_layout,
+            "gridColumnCount": self.grid_column,
+            "gridColumnCountMobile": self.grid_column_mobile,
+            "gridColumnMinWidth": self.grid_column_width,
+            "gridRowHeightFixed": self.grid_row_height,
+            "sort": {
+                "enabled": self.sort,
+                "reverse": self.sort_reverse,
+                "by": self.sort_by,
+            },
+            # Horizontal and vertical axis (from mixins)
+            **self._serialize_grid_config(),
+            **self._serialize_grid_format(),
+            **self._serialize_custom_range(),
+            **self._serialize_custom_ticks(),
+            # Horizontal axis (chart-specific)
+            "x-grid-labels": self.x_grid_labels,
+            "x-grid": self.x_grid_all,
+            "grid-lines-x": {
+                "type": "" if self.x_grid == "off" else self.x_grid,
+                "enabled": self.x_grid != "off",
+            },
+            # Vertical axis (chart-specific)
+            "grid-lines": self.y_grid,
+            "yAxisLabels": {
+                "enabled": self.y_grid_labels != "off",
+                "alignment": self.y_grid_label_align,
+                "placement": "" if self.y_grid_labels == "off" else self.y_grid_labels,
+            },
+            # Appearance
+            "base-color": self.base_color,
+            "negativeColor": NegativeColor.serialize(self.negative_color),
+            "bar-padding": self.bar_padding,
+            "color-category": ColorCategory.serialize(self.color_category),
+            "color-by-column": bool(self.color_category),
+            **PlotHeight.serialize(
+                self.plot_height_mode,
+                self.plot_height_fixed,
+                self.plot_height_ratio,
+            ),
+            "panels": {panel["column"]: panel for panel in self.panels},
+            # Tooltips
+            "show-tooltips": self.show_tooltips,
+            "syncMultipleTooltips": self.sync_multiple_tooltips,
+            "tooltip-number-format": self.tooltip_number_format,
+            # Labels
+            "show-color-key": self.show_color_key,
+            "label-colors": self.label_colors,
+            "label-margin": self.label_margin,
+            **ValueLabels.serialize(
+                self.show_value_labels,
+                self.value_labels_format,
+                placement=self.value_labels_placement,
+                chart_type="multiple-column",
+            ),
+            "xGridLabelAllColumns": self.x_grid_label_all,
+            # Annotations
+            **self._serialize_annotations(
+                text_annotation_class=MultipleColumnTextAnnotation,
+                range_annotation_class=MultipleColumnRangeAnnotation,
+            ),
+        }
+
+        model["metadata"]["visualize"].update(visualize_data)
 
         # Return the serialized data
         return model
@@ -501,15 +772,13 @@ class MultipleColumnChart(BaseChart):
             init_data["sort_reverse"] = False
             init_data["sort_by"] = "end"
 
-        # Horizontal axis
-        init_data["custom_range_x"] = CustomRange.deserialize(
-            visualize.get("custom-range-x")
-        )
-        init_data["custom_ticks_x"] = CustomTicks.deserialize(
-            visualize.get("custom-ticks-x", "")
-        )
-        if "x-grid-format" in visualize:
-            init_data["x_grid_format"] = visualize["x-grid-format"]
+        # Horizontal and vertical axis (from mixins)
+        init_data.update(cls._deserialize_grid_config(visualize))
+        init_data.update(cls._deserialize_grid_format(visualize))
+        init_data.update(cls._deserialize_custom_range(visualize))
+        init_data.update(cls._deserialize_custom_ticks(visualize))
+
+        # Horizontal axis (chart-specific)
         if "x-grid-labels" in visualize:
             init_data["x_grid_labels"] = visualize["x-grid-labels"]
         if "x-grid" in visualize:
@@ -525,16 +794,7 @@ class MultipleColumnChart(BaseChart):
         else:
             init_data["x_grid"] = "off"
 
-        # Vertical axis
-        init_data["custom_range_y"] = CustomRange.deserialize(
-            visualize.get("custom-range-y")
-        )
-        init_data["custom_ticks_y"] = CustomTicks.deserialize(
-            visualize.get("custom-ticks-y", "")
-        )
-        if "y-grid-format" in visualize:
-            init_data["y_grid_format"] = visualize["y-grid-format"]
-
+        # Vertical axis (chart-specific)
         # Parse grid-lines (can be bool or string "show")
         if "grid-lines" in visualize:
             grid_lines_val = visualize["grid-lines"]
@@ -612,11 +872,12 @@ class MultipleColumnChart(BaseChart):
         )
 
         # Annotations
-        init_data["text_annotations"] = TextAnnotation.deserialize_model(
-            visualize.get("text-annotations")
-        )
-        init_data["range_annotations"] = RangeAnnotation.deserialize_model(
-            visualize.get("range-annotations")
+        init_data.update(
+            cls._deserialize_annotations(
+                visualize,
+                text_annotation_class=MultipleColumnTextAnnotation,
+                range_annotation_class=MultipleColumnRangeAnnotation,
+            )
         )
 
         return init_data
