@@ -3,7 +3,6 @@ from typing import Any, Literal
 import pandas as pd
 from pydantic import ConfigDict, Field, field_validator, model_serializer
 
-from .annos import RangeAnnotation, TextAnnotation
 from .base import BaseChart
 from .enums import (
     DateFormat,
@@ -15,10 +14,11 @@ from .enums import (
     ScatterShape,
     ScatterSize,
 )
-from .serializers import ModelListSerializer, PlotHeight
+from .models import AnnotationsMixin
+from .serializers import ColorCategory, PlotHeight
 
 
-class ScatterPlot(BaseChart):
+class ScatterPlot(AnnotationsMixin, BaseChart):
     """A base class for the Datawrapper API's scatter plot chart."""
 
     model_config = ConfigDict(
@@ -198,6 +198,41 @@ class ScatterPlot(BaseChart):
         description="Whether to show the color key",
     )
 
+    #: The column with the color for the points
+    color_column: str = Field(
+        default="",
+        alias="color-column",
+        description="The column with the color for the points",
+    )
+
+    #: A mapping of layer names to colors
+    color_category: dict[str, str] = Field(
+        default_factory=dict,
+        alias="color-category",
+        description="A mapping of layer names to colors",
+    )
+
+    #: Dictionary mapping category names to their display labels in the color legend
+    category_labels: dict[str, str] = Field(
+        default_factory=dict,
+        alias="category-labels",
+        description="Dictionary mapping category names to their display labels in the color legend",
+    )
+
+    #: List defining the order in which categories appear in the chart and legend
+    category_order: list[str] = Field(
+        default_factory=list,
+        alias="category-order",
+        description="List defining the order in which categories appear in the chart and legend",
+    )
+
+    #: A list of columns to exclude from the color key
+    exclude_from_color_key: list[str] = Field(
+        default_factory=list,
+        alias="exclude-from-color-key",
+        description="A list of columns to exclude from the color key",
+    )
+
     #
     # Size
     #
@@ -409,20 +444,6 @@ class ScatterPlot(BaseChart):
     # Annotations
     #
 
-    #: A list of text annotations to display on the chart
-    text_annotations: list[dict[Any, Any]] = Field(
-        default_factory=list,
-        alias="text-annotations",
-        description="A list of text annotations to display on the chart",
-    )
-
-    #: A list of range annotations to display on the chart
-    range_annotations: list[dict[Any, Any]] = Field(
-        default_factory=list,
-        alias="range-annotations",
-        description="A list of range annotations to display on the chart",
-    )
-
     #: Add custom lines on the chart
     custom_lines: str = Field(
         default="",
@@ -435,9 +456,9 @@ class ScatterPlot(BaseChart):
     #
 
     #: The column to use for the labels
-    labels_column: str | None = Field(
+    label_column: str | None = Field(
         default=None,
-        alias="labels-column",
+        alias="label-column",
         description="The column to use for the labels",
     )
 
@@ -510,11 +531,13 @@ class ScatterPlot(BaseChart):
             axes["size"] = self.size_column
         if self.shape_column:
             axes["shape"] = self.shape_column
-        if self.labels_column:
-            axes["labels"] = self.labels_column
+        if self.label_column:
+            axes["labels"] = self.label_column
+        if self.color_column:
+            axes["color"] = self.color_column
 
         # Add axes to metadata
-        model["axes"] = axes
+        model["metadata"]["axes"] = axes
 
         # Add chart specific properties to visualize section
         model["metadata"]["visualize"].update(
@@ -543,6 +566,13 @@ class ScatterPlot(BaseChart):
                 "outlines": self.outlines,
                 "color-outline": self.color_outline,
                 "show-color-key": self.show_color_key,
+                "color-category": ColorCategory.serialize(
+                    self.color_category,
+                    self.category_labels,
+                    self.category_order,
+                    self.exclude_from_color_key,
+                ),
+                "color-by-column": bool(self.color_category),
                 # Size
                 "size": self.size,
                 "fixed-size": self.fixed_size,
@@ -573,12 +603,7 @@ class ScatterPlot(BaseChart):
                     self.plot_height_ratio,
                 ),
                 # Annotations
-                "text-annotations": ModelListSerializer.serialize(
-                    self.text_annotations, TextAnnotation
-                ),
-                "range-annotations": ModelListSerializer.serialize(
-                    self.range_annotations, RangeAnnotation
-                ),
+                **self._serialize_annotations(),
                 "custom-lines": self.custom_lines,
                 # Labeling
                 "auto-labels": self.auto_labels,
@@ -615,15 +640,16 @@ class ScatterPlot(BaseChart):
         # Extract scatter-specific sections
         metadata = api_response.get("metadata", {})
         visualize = metadata.get("visualize", {})
-        # Axes can be at top level or in metadata
-        axes = api_response.get("axes", metadata.get("axes", {}))
+        axes = metadata.get("axes", {})
 
         # Parse axes columns
         init_data["x_column"] = axes.get("x")
         init_data["y_column"] = axes.get("y")
         init_data["size_column"] = axes.get("size")
         init_data["shape_column"] = axes.get("shape")
-        init_data["labels_column"] = axes.get("labels")
+        init_data["label_column"] = axes.get("labels")
+        if "color" in axes:
+            init_data["color_column"] = axes["color"]
 
         # Parse x-axis
         x_axis = visualize.get("x-axis", {})
@@ -673,6 +699,9 @@ class ScatterPlot(BaseChart):
         if "show-color-key" in visualize:
             init_data["show_color_key"] = visualize["show-color-key"]
 
+        # Parse color-category using utility
+        init_data.update(ColorCategory.deserialize(visualize.get("color-category")))
+
         # Size
         if "size" in visualize:
             init_data["size"] = visualize["size"]
@@ -733,12 +762,7 @@ class ScatterPlot(BaseChart):
         init_data.update(PlotHeight.deserialize(visualize))
 
         # Annotations
-        init_data["text_annotations"] = TextAnnotation.deserialize_model(
-            visualize.get("text-annotations")
-        )
-        init_data["range_annotations"] = RangeAnnotation.deserialize_model(
-            visualize.get("range-annotations")
-        )
+        init_data.update(cls._deserialize_annotations(visualize))
 
         if "custom-lines" in visualize:
             init_data["custom_lines"] = visualize["custom-lines"]
