@@ -28,14 +28,14 @@ class TestArrowChartCreation:
     """Tests for ArrowChart creation and serialization."""
 
     def test_serialize_with_axis_colors_and_labels(self):
-        """Test serializing with axis_colors and axis_labels."""
+        """Test serializing with color_column and label_column."""
         chart = ArrowChart(
             title="Test",
             data=pd.DataFrame({"Country": ["A", "B"], "Start": [1, 2], "End": [3, 4]}),
-            axis_start="Start",
-            axis_end="End",
-            axis_colors="Country",
-            axis_labels="Country",
+            start_column="Start",
+            end_column="End",
+            color_column="Country",
+            label_column="Country",
         )
 
         serialized = chart.serialize_model()
@@ -43,6 +43,58 @@ class TestArrowChartCreation:
         assert serialized["metadata"]["axes"]["colors"] == "Country"
         assert serialized["metadata"]["axes"]["labels"] == "Country"
 
+    def test_serialize_conditional_axes_fields(self):
+        """Test that axes fields are only included when non-None (conditional serialization)."""
+        # Test with only start and end columns (minimal axes)
+        chart = ArrowChart(
+            title="Test",
+            data=pd.DataFrame({"x": [1, 2], "y": [10, 20], "z": [15, 25]}),
+            start_column="y",
+            end_column="z",
+        )
+
+        serialized = chart.serialize_model()
+
+        # Should only include start and end
+        assert "axes" in serialized["metadata"]
+        assert serialized["metadata"]["axes"]["start"] == "y"
+        assert serialized["metadata"]["axes"]["end"] == "z"
+        assert "colors" not in serialized["metadata"]["axes"]
+        assert "labels" not in serialized["metadata"]["axes"]
+
+    def test_serialize_no_axes_when_all_none(self):
+        """Test that axes section is omitted when all axes fields are None."""
+        chart = ArrowChart(
+            title="Test",
+            data=pd.DataFrame({"x": [1, 2], "y": [10, 20]}),
+            # No axes columns specified
+        )
+
+        serialized = chart.serialize_model()
+
+        # axes section should not be present at all
+        assert "axes" not in serialized["metadata"]
+
+    def test_serialize_partial_axes_fields(self):
+        """Test serializing with only some axes fields set."""
+        # Test with start, end, and color but no label
+        chart = ArrowChart(
+            title="Test",
+            data=pd.DataFrame({"Country": ["A", "B"], "Start": [1, 2], "End": [3, 4]}),
+            start_column="Start",
+            end_column="End",
+            color_column="Country",
+            # label_column intentionally omitted
+        )
+
+        serialized = chart.serialize_model()
+
+        assert "axes" in serialized["metadata"]
+        assert serialized["metadata"]["axes"]["start"] == "Start"
+        assert serialized["metadata"]["axes"]["end"] == "End"
+        assert serialized["metadata"]["axes"]["colors"] == "Country"
+        assert "labels" not in serialized["metadata"]["axes"]
+
     def test_create_basic_arrow_chart(self):
         """Test creating a basic arrow chart."""
         chart = ArrowChart(
@@ -54,23 +106,23 @@ class TestArrowChartCreation:
                     "2023": [110, 160, 115, 95],
                 }
             ),
-            axis_start="2020",
-            axis_end="2023",
+            start_column="2020",
+            end_column="2023",
         )
 
         assert chart.chart_type == "d3-arrow-plot"
         assert chart.title == "Test Arrow Chart"
         assert isinstance(chart.data, pd.DataFrame)
-        assert chart.axis_start == "2020"
-        assert chart.axis_end == "2023"
+        assert chart.start_column == "2020"
+        assert chart.end_column == "2023"
 
     def test_serialize_arrow_chart(self):
         """Test serializing an arrow chart."""
         chart = ArrowChart(
             title="Test Chart",
             data=pd.DataFrame({"Region": ["A"], "Start": [10], "End": [20]}),
-            axis_start="Start",
-            axis_end="End",
+            start_column="Start",
+            end_column="End",
             thick_arrows=True,
             y_grid="on",
         )
@@ -89,8 +141,8 @@ class TestArrowChartCreation:
         chart = ArrowChart(
             title="Test",
             data=pd.DataFrame({"x": [1, 2], "y": [10, 20], "z": [15, 25]}),
-            axis_start="y",
-            axis_end="z",
+            start_column="y",
+            end_column="z",
             sort_ranges=True,
             sort_by="difference",
             reverse_order=True,
@@ -109,8 +161,8 @@ class TestArrowChartCreation:
             data=pd.DataFrame(
                 {"Country": ["US", "UK"], "2020": [10, 20], "2023": [15, 25]}
             ),
-            axis_start="2020",
-            axis_end="2023",
+            start_column="2020",
+            end_column="2023",
             replace_flags="4x3",
         )
 
@@ -124,8 +176,8 @@ class TestArrowChartCreation:
         chart = ArrowChart(
             title="Test",
             data=pd.DataFrame({"x": [1], "y": [10], "z": [20]}),
-            axis_start="y",
-            axis_end="z",
+            start_column="y",
+            end_column="z",
             replace_flags="off",
         )
 
@@ -139,8 +191,8 @@ class TestArrowChartCreation:
         chart = ArrowChart(
             title="Test",
             data=pd.DataFrame({"x": [1, 2], "y": [10, 20], "z": [15, 25]}),
-            axis_start="y",
-            axis_end="z",
+            start_column="y",
+            end_column="z",
             color_category={"Series A": "#ff0000", "Series B": "#0000ff"},
         )
 
@@ -156,16 +208,14 @@ class TestArrowChartCreation:
         chart = ArrowChart(
             title="Test",
             data=pd.DataFrame({"x": [1, 2], "y": [10, 20], "z": [15, 25]}),
-            axis_start="y",
-            axis_end="z",
-            color_by_column=True,
-            group_by_column=True,
+            start_column="y",
+            end_column="z",
+            groups_column="x",  # Setting groups_column should enable group-by-column
             arrow_key=True,
         )
 
         serialized = chart.serialize_model()
 
-        assert serialized["metadata"]["visualize"]["color-by-column"] is True
         assert serialized["metadata"]["visualize"]["group-by-column"] is True
         assert serialized["metadata"]["visualize"]["show-arrow-key"] is True
 
@@ -174,8 +224,8 @@ class TestArrowChartCreation:
         chart = ArrowChart(
             title="Test",
             data=pd.DataFrame({"x": [1, 2], "y": [10, 20], "z": [15, 25]}),
-            axis_start="y",
-            axis_end="z",
+            start_column="y",
+            end_column="z",
             value_label_format="0.0%",
             range_value_labels="both",
         )
@@ -190,8 +240,8 @@ class TestArrowChartCreation:
         chart = ArrowChart(
             title="Test",
             data=pd.DataFrame({"x": [1, 2], "y": [10, 20], "z": [15, 25]}),
-            axis_start="y",
-            axis_end="z",
+            start_column="y",
+            end_column="z",
             custom_range=[0, 100],
             range_extent="custom",
         )
@@ -233,14 +283,13 @@ class TestArrowChartGet:
             )
 
             # Verify axes
-            assert chart.axis_start == "1950"
-            assert chart.axis_end == "2022"
+            assert chart.start_column == "1950"
+            assert chart.end_column == "2022"
 
             # Verify features
             assert chart.thick_arrows is True
             assert chart.arrow_key is True
-            assert chart.color_by_column is True
-            assert chart.group_by_column is True
+            assert chart.groups_column == "Gender"
 
             # Verify sorting
             assert chart.sort_ranges is False
@@ -421,8 +470,8 @@ class TestArrowChartIntegration:
                     "2023": [110, 160, 115, 95],
                 }
             ),
-            axis_start="2020",
-            axis_end="2023",
+            start_column="2020",
+            end_column="2023",
             thick_arrows=True,
             sort_ranges=True,
             sort_by="difference",
@@ -435,7 +484,8 @@ class TestArrowChartIntegration:
 
         # Create the chart
         with patch.object(original_chart, "_get_client", return_value=mock_client):
-            chart_id = original_chart.create(access_token="test-token")
+            original_chart.create(access_token="test-token")
+            chart_id = original_chart.chart_id
 
         # Now fetch it back
         serialized = original_chart.serialize_model()
@@ -465,8 +515,8 @@ class TestArrowChartIntegration:
             # Verify key fields match
             assert fetched_chart.title == original_chart.title
             assert fetched_chart.chart_type == original_chart.chart_type
-            assert fetched_chart.axis_start == original_chart.axis_start
-            assert fetched_chart.axis_end == original_chart.axis_end
+            assert fetched_chart.start_column == original_chart.start_column
+            assert fetched_chart.end_column == original_chart.end_column
             assert fetched_chart.thick_arrows == original_chart.thick_arrows
             assert fetched_chart.sort_ranges == original_chart.sort_ranges
             assert fetched_chart.sort_by == original_chart.sort_by
