@@ -485,7 +485,7 @@ class TestBarChartGet:
             assert chart.label_column == "Country"
             assert chart.bar_column == "Value"
             assert chart.color_column == "Category"
-            assert chart.group_by_column == "Region"
+            assert chart.groups_column == "Region"
 
     def test_get_bar_chart_replace_flags_enabled(self):
         """Test get() correctly parses replace-flags when enabled."""
@@ -587,7 +587,8 @@ class TestChartGetIntegration:
 
         # Create the chart
         with patch.object(original_chart, "_get_client", return_value=mock_client):
-            chart_id = original_chart.create(access_token="test-token")
+            original_chart.create(access_token="test-token")
+            chart_id = original_chart.chart_id
 
         # Now fetch it back
         serialized = original_chart.serialize_model()
